const { __ } = wp.i18n;
const { createElement, Fragment, useState } = wp.element;
const { registerPlugin } = wp.plugins;
const { PluginSidebar, PluginSidebarMoreMenuItem } = wp.editPost;
const { PanelBody, Button, TextControl, SelectControl } = wp.components;
const { select } = wp.data;

function AI_Content_Assistant() {
    const [customPrompt, setCustomPrompt] = useState('');
    const [selectedProvider, setSelectedProvider] = useState(aiContentAssistant.defaultProvider);
    
    const providers = Object.entries(aiContentAssistant.providers).map(([key, provider]) => ({
        value: key,
        label: provider.name
    }));

    const handlePrompt = (promptText) => {
        const content = select('core/editor').getEditedPostContent();
        const provider = aiContentAssistant.providers[selectedProvider];
        
        // Create the full prompt text
        const fullPrompt = promptText + "\n\n" + content;
        
        // Copy to clipboard
        navigator.clipboard.writeText(fullPrompt).then(() => {
            // Open AI provider in new tab
            window.open(provider.url, '_blank');
        }).catch(err => {
            console.error('Failed to copy text:', err);
            // If clipboard fails, open a modal with the text
            const modal = document.createElement('div');
            modal.style.cssText = 'position:fixed;top:50%;left:50%;transform:translate(-50%,-50%);background:white;padding:20px;border-radius:8px;box-shadow:0 2px 10px rgba(0,0,0,0.1);z-index:10000;max-width:80%;max-height:80%;overflow:auto;';
            modal.innerHTML = `
                <h3>Copy this text and paste it into ${provider.name}:</h3>
                <textarea style="width:100%;height:200px;margin:10px 0;">${fullPrompt}</textarea>
                <button onclick="this.parentElement.remove();window.open('${provider.url}', '_blank')" style="padding:8px 16px;">
                    Open ${provider.name}
                </button>
            `;
            document.body.appendChild(modal);
        });
    };

    return createElement(Fragment, {},
        createElement(PluginSidebarMoreMenuItem, {
            target: 'ai-content-assistant'
        }, __('AI Content Assistant', 'ai-content-assistant')),

        createElement(PluginSidebar, {
            name: 'ai-content-assistant',
            title: __('AI Content Assistant', 'ai-content-assistant')
        },
            createElement(PanelBody, {},
                createElement(SelectControl, {
                    label: __('AI Provider', 'ai-content-assistant'),
                    value: selectedProvider,
                    options: providers,
                    onChange: setSelectedProvider
                }),

                // Quick prompt buttons
                createElement('div', { className: 'quick-prompts' },
                    aiContentAssistant.defaultPrompts.map((prompt, index) => 
                        createElement(Button, {
                            key: index,
                            isSecondary: true,
                            onClick: () => handlePrompt(prompt),
                            className: 'quick-prompt-button'
                        }, prompt)
                    )
                ),

                // Custom prompt input
                createElement(TextControl, {
                    label: __('Custom Prompt', 'ai-content-assistant'),
                    value: customPrompt,
                    onChange: setCustomPrompt,
                    placeholder: __('Enter your prompt here', 'ai-content-assistant')
                }),

                createElement(Button, {
                    isPrimary: true,
                    onClick: () => {
                        if (customPrompt.trim()) {
                            handlePrompt(customPrompt);
                            setCustomPrompt('');
                        }
                    },
                    disabled: !customPrompt.trim(),
                    className: 'custom-prompt-button'
                }, __('Send Custom Prompt', 'ai-content-assistant'))
            )
        )
    );
}

registerPlugin('ai-content-assistant', {
    render: AI_Content_Assistant,
    icon: 'admin-customizer'
});