jQuery(document).ready(function($) {
    // Add button to editor toolbar
    var button = $('<button/>', {
        text: 'Analyze Content',
        class: 'button content-analyzer-button',
        click: function(e) {
            e.preventDefault();
            analyzeContent();
        }
    });

    $('.wp-editor-tools').append(button);

    // Create analysis modal
    var modal = $('<div/>', {
        class: 'content-analyzer-modal',
        html: `
            <div class="content-analyzer-modal-content">
                <h2>Content Analysis</h2>
                <div class="analysis-results"></div>
                <div class="spinner" style="display: none;"></div>
                <div class="error-message"></div>
                <button class="button close-modal">Close</button>
            </div>
        `
    }).appendTo('body');

    // Close modal on button click
    modal.find('.close-modal').on('click', function() {
        modal.hide();
    });

    // Close modal on outside click
    $(window).on('click', function(e) {
        if ($(e.target).is(modal)) {
            modal.hide();
        }
    });

    function getContent() {
        if (tinyMCE && tinyMCE.activeEditor && !tinyMCE.activeEditor.isHidden()) {
            return tinyMCE.activeEditor.getContent();
        } else {
            return $('#content').val();
        }
    }

    async function analyzeContent() {
        const content = getContent();
        const resultsDiv = modal.find('.analysis-results');
        const spinner = modal.find('.spinner');
        const errorDiv = modal.find('.error-message');

        // Reset and show modal
        resultsDiv.empty();
        errorDiv.empty();
        spinner.show();
        modal.show();

        try {
            const response = await fetch(contentAnalyzerData.ajaxurl, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: new URLSearchParams({
                    action: 'analyze_content',
                    nonce: contentAnalyzerData.nonce,
                    content: content
                })
            });

            const data = await response.json();

            if (data.success) {
                resultsDiv.html(data.data);
            } else {
                errorDiv.text(data.data || 'Error analyzing content');
            }
        } catch (err) {
            errorDiv.text('Failed to analyze content: ' + err.message);
        } finally {
            spinner.hide();
        }
    }
});